@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
@@ -14,7 +14,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-ses", "1.63.0", __name__[0:-6], "aws-ses@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-ses", "1.64.0", __name__[0:-6], "aws-ses@1.64.0.jsii.tgz"
 )
 
 __all__ = [
